pub struct CompositeCompletionHandler { /* private fields */ }Expand description
Composite completion handler that combines multiple handlers
This handler allows you to combine different completion strategies and provides a unified interface for complex completion scenarios.
Example
use prism_mcp_rs::core::completion_handlers::{
CompositeCompletionHandler, FuzzyCompletionHandler, FileSystemCompletionHandler
};
let composite = CompositeCompletionHandler::new()
.add_handler("files", FileSystemCompletionHandler::new("/home/user"))
.add_handler("prompts", FuzzyCompletionHandler::new(vec!["analyze", "create", "generate"]));Implementations
Sourceimpl CompositeCompletionHandler
impl CompositeCompletionHandler
Sourcepub fn add_handler<H>(self, name: &str, handler: H) -> Selfwhere
H: CompletionHandler + 'static,
pub fn add_handler<H>(self, name: &str, handler: H) -> Selfwhere
H: CompletionHandler + 'static,
Add a named completion handler
Arguments
name- Identifier for this handler (used for routing)handler- The completion handler implementation
Sourcepub fn with_default<H>(self, handler: H) -> Selfwhere
H: CompletionHandler + 'static,
pub fn with_default<H>(self, handler: H) -> Selfwhere
H: CompletionHandler + 'static,